==> phplist-2.10.19.zip: phplist-2.10.19/public_html/lists/admin/info/it/vote.php <==


<p><b>Vota PHPlist</b><br/>
Se pensi che PHPlist sia un buon programma e vuoi consigliare a pi&ugrave; persone di utilizzarlo, perch&eacute; non invii il tuo giudizio a questi siti:
</p>
<p>Se trovi PHPlist in altri siti e pensi che il sito debba essere incluso qui, <a href="mailto:phplist2@tincan.co.uk?subject=New Directory">invia una semplice email</a></p>
<ul>
<li><b>Su freshmeat</b>
<form method="post" action="http://freshmeat.net/rate/store/" target="_vote">
  <input type="hidden" name="project_id" value="7994">
<table cellspacing="3" cellpadding="0" border="0">
  <tr>
    <td valign="middle" width="15%">
  <b>Valutazione:</b>
    </td>
  <td valign="top" width="85%">
  <select name="rating" onchange="submit()">

  <option value="">-
      <option value="1">1</option>
      <option value="2">2</option>
      <option value="3">3</option>
      <option value="4">4</option>
      <option value="5">5</option>
      <option value="6">6</option>

      <option value="7">7</option>
      <option value="8">8</option>
      <option value="9">9</option>
      <option value="10" selected>10</option>
    </select>
  <input type="submit" value="Vota">
    </td>
  </tr>
</table>
</form>
</li>
<li><b>Su codetransit</b>
<TABLE CELLPADDING=1 CELLSPACING=0 BORDER=0 BGCOLOR=#000000><TR><TD>
<TABLE border="0" cellspacing="0" cellpadding="4" align="center" style="font-family:verdana;font-size:10px;" bgcolor=#EEEEEE>
<FORM name="rate" method="post" action="http://www.codetransit.com/action.php?action=rate&linkid=19">
<TR bgcolor=gray>
<TD colspan="3" style="color:#FFFFFF"><strong>Vota questo prodotto su Code Transit</strong></TD>
</TR>
<TR>
<TD><INPUT type="radio" value="5" name="form_rate_radio_vote" checked ></TD>
<TD><IMG src="http://www.codetransit.com/themes/advanced/rating/5.gif" width="75" height="13"></TD>
<TD>Eccellente!</TD>
</TR>
<TR>
<TD><INPUT type="radio" value="4" name="form_rate_radio_vote"></TD>
<TD><IMG src="http://www.codetransit.com/themes/advanced/rating/4.gif" width="75" height="13"></TD>
<TD>Veramente buono</TD>
</TR>
<TR>
<TD><INPUT type="radio" value="3" name="form_rate_radio_vote"></TD>
<TD><IMG src="http://www.codetransit.com/themes/advanced/rating/3.gif" width="75" height="13"></TD>
<TD>Buono</TD>
</TR>
<TR>
<TD><INPUT type="radio" value="2" name="form_rate_radio_vote"></TD>
<TD><IMG src="http://www.codetransit.com/themes/advanced/rating/2.gif" width="75" height="13"></TD>
<TD>Imparziale</TD>
</TR>
<TR>
<TD><INPUT type="radio" value="1" name="form_rate_radio_vote"></TD>
<TD><IMG src="http://www.codetransit.com/themes/advanced/rating/1.gif" width="75" height="13"></TD>
<TD>Povero</TD>
</TR>
<TR>
<TD colspan="3"><INPUT type="submit" name="form_rate_button_rate" value="Vota"></TD>
</TR>
</FORM>
</TABLE>
</TD></TR></TABLE> o scrivi a <a href="http://www.codetransit.com/index.php?id=19&t=add_review" target="_review">Recensione</a>
<br/><br/></li>
<li><b>Su PHPWelt</b> (german)
<form action="http://www.phpwelt.de/archiv/arcscript.php" method="post" target="_vote">
<select name="arcwert" class="vote">
<option selected>10
<option>9
<option>8
<option>7
<option>6
<option>5
<option>4
<option>3
<option>2
<option>1
</select>
<input type="submit" value="Vota">
<input type="hidden" name="ack_vote" value="TRUE">
<input type="hidden" name="arcid" value="226">
</form>
</li>
<li><b>Su resourceindex</b><br/>
<a href="http://php.resourceindex.com/detail/00074.html" target="_vote">Vota PHPlist</a><br/><br/>
</li>
<li><b>Su <a href="http://www.hotscripts.com/?RID=9619">Hotscripts</a></b><br/>
<form action="http://www.hotscripts.com/cgi-bin/rate.cgi" method="POST">
<input type=hidden name="ID" value="5015">
<table BORDER="0" CELLSPACING="0" CELLPADDING="2" bgcolor="#CCCC99">
<tr><td><span class="highlight"><b>Cabina elettorale visitatori: </b></span></td>
<td><select name="rate" size="1"><option selected>Seleziona il tuo giudizio</option>
<option value="5" selected>Eccellente!</option><option value="4">Veramente Buono</option>
<option value="3">Buono</option><option value="2">Imparziale</option>
<option value="1">povero</option></select></td><td>
<input type="submit" value="Votami!"></td></tr></table></form>
<a href="http://www.hotscripts.com/review/?linkid=5015&returnto=http://www.hotscripts.com/Detailed/5015.html" target="_review">Scrivi una Recensione</a><br/><br/>

</li>
<li><b>Su Devscripts.com</b>
<form action="http://devscripts.com/vote.php" method="post" name="frmRate" target="_vote">
<input type="hidden" name="strScriptId" value="1465">
    <select name="strRValue" onChange="document.frmRate.submit();">
        <option value="NULL">Giudizio</option>
        <option value="10" selected>10</option>

        <option value="9">9</option>
        <option value="8">8</option>
        <option value="7">7</option>
        <option value="6">6</option>
        <option value="5">5</option>
        <option value="4">4</option>

        <option value="3">3</option>
        <option value="2">2</option>
        <option value="1">1</option>
    </select><input type="submit" value="Vota">
</form>
<a href="http://devscripts.com/review.php?sId=1465" target="_review">Scrivi una Recensione</a><br/><br/>
</li>
<li><b>Su webscript.ru</b> (russian)<br/>
<form name="rate" method="post" action="http://webscript.ru/action.php?sid=598201422&action=rate&linkid=22&having=753">
5 <input type="radio" value="5" name="form_rate_radio_vote" checked>
4  <input type="radio" value="4" name="form_rate_radio_vote">
3 <input type="radio" value="3" name="form_rate_radio_vote">
2 <input type="radio" value="2" name="form_rate_radio_vote">
1 <input type="radio" value="1" name="form_rate_radio_vote">
<input type="submit" name="form_rate_button_rate" class="button" value="Vota">
</form>
</li>
<li><b>Su PHPindex.com</b> (french)<br/>
<a href="http://www.phpindex.com/annuaire/annuaire_critique.php3?annuaire_critique_annuaire_id=917">Scrivi una Recensione</a><br/><br/>
</li>
<li><b>Su bigboys</b><br/>
<form method="GET" action="http://www.big-boys.com/php/vote1.asp">
    <select size="1" name="F1">
      <option VALUE="1">1 - Povero
      <option VALUE="2">2
      <option VALUE="3">3
      <option VALUE="4">4
      <option VALUE="5">5 - Mediocre
      <option VALUE="6">6
      <option VALUE="7">7
      <option VALUE="8">8
      <option VALUE="9">9
      <option VALUE="10" selected>10 - Eccelente
      <input Type="Hidden" Name="ID" Value="151">
    </select>
    <input type="submit" value="Vota">
</form>

==> phplist-3.6.15.zip: phplist-3.6.15/public_html/lists/admin/info/it/vote.php <==


<p><b>Vota PHPlist</b><br/>
Se pensate che PHPlist sia un buon programma, e volete consigliare a pi&ugrave; persone di utilizzarlo, perch&egrave; non date il vostro voto in alcuni di questi siti?
</p>
<p>Se trovate PHPlist in altri siti, e pensate che il sito debba essere incluso qu&igrave;, <a href="mailto:phplist2@tincan.co.uk?subject=New Directory">inviateci semplicemente una email.</a></p>
<ul>
<li><b>Su freshmeat</b>
<form method="post" action="http://freshmeat.net/rate/store/" target="_vote">
  <input type="hidden" name="project_id" value="7994">
<table cellspacing="3" cellpadding="0" border="0">
  <tr>
    <td valign="middle" width="15%">
  <b>Valutazione:</b>
    </td>
  <td valign="top" width="85%">
  <select name="rating" onchange="submit()">

  <option value="">-
      <option value="1">1</option>
      <option value="2">2</option>
      <option value="3">3</option>
      <option value="4">4</option>
      <option value="5">5</option>
      <option value="6">6</option>

      <option value="7">7</option>
      <option value="8">8</option>
      <option value="9">9</option>
      <option value="10" selected>10</option>
    </select>
  <input type="submit" value="Vota">
    </td>
  </tr>
</table>
</form>
</li>
<li><b>Su codetransit</b>
<TABLE CELLPADDING=1 CELLSPACING=0 BORDER=0 BGCOLOR=#000000><TR><TD>
<TABLE border="0" cellspacing="0" cellpadding="4" align="center" style="font-family:verdana;font-size:10px;" bgcolor=#EEEEEE>
<FORM name="rate" method="post" action="http://www.codetransit.com/action.php?action=rate&linkid=19">
<TR bgcolor=gray>
<TD colspan="3" style="color:#FFFFFF"><strong>Vota questo prodotto su Code Transit</strong></TD>
</TR>
<TR>
<TD><INPUT type="radio" value="5" name="form_rate_radio_vote" checked ></TD>
<TD><IMG src="http://www.codetransit.com/themes/advanced/rating/5.gif" width="75" height="13"></TD>
<TD>Eccellente!</TD>
</TR>
<TR>
<TD><INPUT type="radio" value="4" name="form_rate_radio_vote"></TD>
<TD><IMG src="http://www.codetransit.com/themes/advanced/rating/4.gif" width="75" height="13"></TD>
<TD>Veramente buono</TD>
</TR>
<TR>
<TD><INPUT type="radio" value="3" name="form_rate_radio_vote"></TD>
<TD><IMG src="http://www.codetransit.com/themes/advanced/rating/3.gif" width="75" height="13"></TD>
<TD>Buono</TD>
</TR>
<TR>
<TD><INPUT type="radio" value="2" name="form_rate_radio_vote"></TD>
<TD><IMG src="http://www.codetransit.com/themes/advanced/rating/2.gif" width="75" height="13"></TD>
<TD>Imparziale</TD>
</TR>
<TR>
<TD><INPUT type="radio" value="1" name="form_rate_radio_vote"></TD>
<TD><IMG src="http://www.codetransit.com/themes/advanced/rating/1.gif" width="75" height="13"></TD>
<TD>Povero</TD>
</TR>
<TR>
<TD colspan="3"><INPUT type="submit" name="form_rate_button_rate" value="Vota"></TD>
</TR>
</FORM>
</TABLE>
</TD></TR></TABLE> o scrivi a <a href="http://www.codetransit.com/index.php?id=19&t=add_review" target="_review">Recensione</a>
<br/><br/></li>
<li><b>Su PHPWelt</b> (german)
<form action="http://www.phpwelt.de/archiv/arcscript.php" method="post" target="_vote">
<select name="arcwert" class="vote">
<option selected>10
<option>9
<option>8
<option>7
<option>6
<option>5
<option>4
<option>3
<option>2
<option>1
</select>
<input type="submit" value="Vota">
<input type="hidden" name="ack_vote" value="TRUE">
<input type="hidden" name="arcid" value="226">
</form>
</li>
<li><b>Su resourceindex</b><br/>
<a href="http://php.resourceindex.com/detail/00074.html" target="_vote">Vota PHPlist</a><br/><br/>
</li>
<li><b>Su <a href="http://www.hotscripts.com/?RID=9619">Hotscripts</a></b><br/>
<form action="http://www.hotscripts.com/cgi-bin/rate.cgi" method="POST">
<input type=hidden name="ID" value="5015">
<table BORDER="0" CELLSPACING="0" CELLPADDING="2" bgcolor="#CCCC99">
<tr><td><span class="highlight"><b>Cabina elettorale visitatori: </b></span></td>
<td><select name="rate" size="1"><option selected>Seleziona il tuo giudizio</option>
<option value="5" selected>Eccellente!</option><option value="4">Veramente Buono</option>
<option value="3">Buono</option><option value="2">Imparziale</option>
<option value="1">Povero</option></select></td><td>
<input type="submit" value="Votami!"></td></tr></table></form>
<a href="http://www.hotscripts.com/review/?linkid=5015&returnto=http://www.hotscripts.com/Detailed/5015.html" target="_review">Scrivi una Recensione</a><br/><br/>

</li>
<li><b>Su Devscripts.com</b>
<form action="http://devscripts.com/vote.php" method="post" name="frmRate" target="_vote">
<input type="hidden" name="strScriptId" value="1465">
    <select name="strRValue" onChange="document.frmRate.submit();">
        <option value="NULL">Giudizio</option>
        <option value="10" selected>10</option>

        <option value="9">9</option>
        <option value="8">8</option>
        <option value="7">7</option>
        <option value="6">6</option>
        <option value="5">5</option>
        <option value="4">4</option>

        <option value="3">3</option>
        <option value="2">2</option>
        <option value="1">1</option>
    </select><input type="submit" value="Vota">
</form>
<a href="http://devscripts.com/review.php?sId=1465" target="_review">Scrivi una Recensione</a><br/><br/>
</li>
<li><b>Su webscript.ru</b> (russian)<br/>
<form name="rate" method="post" action="http://webscript.ru/action.php?sid=598201422&action=rate&linkid=22&having=753">
5 <input type="radio" value="5" name="form_rate_radio_vote" checked>
4  <input type="radio" value="4" name="form_rate_radio_vote">
3 <input type="radio" value="3" name="form_rate_radio_vote">
2 <input type="radio" value="2" name="form_rate_radio_vote">
1 <input type="radio" value="1" name="form_rate_radio_vote">
<input type="submit" name="form_rate_button_rate" class="button" value="Vota">
</form>
</li>
<li><b>Su PHPindex.com</b> (french)<br/>
<a href="http://www.phpindex.com/annuaire/annuaire_critique.php3?annuaire_critique_annuaire_id=917">Scrivi una Recensione</a><br/><br/>
</li>
<li><b>Su bigboys</b><br/>
<form method="GET" action="http://www.big-boys.com/php/vote1.asp">
    <select size="1" name="F1">
      <option VALUE="1">1 - Povero
      <option VALUE="2">2
      <option VALUE="3">3
      <option VALUE="4">4
      <option VALUE="5">5 - Mediocre
      <option VALUE="6">6
      <option VALUE="7">7
      <option VALUE="8">8
      <option VALUE="9">9
      <option VALUE="10" selected>10 - Eccellente
      <input Type="Hidden" Name="ID" Value="151">
    </select>
    <input type="submit" value="Vota">
</form>
